import { ExtendedTable } from './extended-table';
import { Construct } from 'constructs';
import { GlobalSecondaryIndexProps, TableProps } from 'aws-cdk-lib/aws-dynamodb';
type StandardGlobalSecondaryIndexProps = Partial<GlobalSecondaryIndexProps>;
type StandardTablePropsOmitFields = 'tableName' | 'partitionKey' | 'sortKey';
export interface StandardTableProps extends Omit<TableProps, StandardTablePropsOmitFields> {
    /**
     * Setting this to true will suppress the creation of default tags on resources
     * created by this construct. Default is false.
     *
     * @default - false
     */
    readonly suppressTagging?: boolean;
    /**
     * Creates additional global secondary indexes on the table with the partition key Gs#Pk and sort key Gs#Sk of string types. Default is 1.
     * Be aware you may only add one index at a time if the table already exists. This is a limitation of the DynamoDB API.
     *
     * @default 1
     */
    readonly globalSecondaryIndexes?: number;
}
/**
 * Standard DynamoDB table with a defined primary key, sort key and secondary index. This
 * class is intended to fit most development use cases. Where this class does not meet
 * your requirements, use ExtendedTable directly.
 */
export declare class StandardTable extends ExtendedTable {
    protected secondaryIndexCount: number;
    constructor(scope: Construct, id: string, props?: StandardTableProps);
    /**
     * Add a global secondary index of table.
     *
     * @param props the property of global secondary index
     */
    addGlobalSecondaryIndex(props: StandardGlobalSecondaryIndexProps): void;
}
export {};
