import { Bucket, BucketProps } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
import { CacheControl, ISource } from 'aws-cdk-lib/aws-s3-deployment';
/**
 * Properties for convenience deploy method in ExtendedBucket.
 */
export interface BucketDeploymentConfig {
    /**
     * The paths or sources to deploy.
     */
    readonly source: string | string[] | ISource | ISource[];
    /**
     * Prefix to add to the deployment path in the bucket.
     */
    readonly prefix?: string;
    /**
     * Paths to exclude from the deployment.
     */
    readonly exclude?: string | string[];
    /**
     * Additional Cache-Control directives to set. Default is none.
     */
    readonly cacheControl?: CacheControl[];
    /**
     * Whether to prune objects that exist in the bucket but not in the assets. Default is false.
     */
    readonly prune?: boolean;
}
export type ExtendedBucketProps = BucketProps;
/**
 * Extension of Bucket with preset defaults that include, disallowing public access,
 * enforcing bucket owner object ownership, S3 managed encryption, and auto deletion
 * of objects when removal policy is set to DESTROY. Also includes convenience methods
 * for things like S3 deployments.
 */
export declare class ExtendedBucket extends Bucket {
    protected deployCount: number;
    constructor(scope: Construct, id: string, props: ExtendedBucketProps);
    protected nextDeployCount(): string;
    deploy(config: BucketDeploymentConfig | BucketDeploymentConfig[]): void;
}
